==> ironmailer-0.8-src.tar.bz2: src/logic/net/jatec/ironmailer/controller/action/AddressesAction.java <==
/* 
 *   Copyright (C) 2002, 2003 Jatec AG, Switzerland
 *
 * This file is part of IronMailer.
 *
 * IronMailer is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

package net.jatec.ironmailer.controller.action;

import java.util.Map;
import javax.servlet.ServletRequest;
import org.apache.cocoon.environment.Redirector;
import org.apache.log4j.Logger;

import net.jatec.ironmailer.controller.ControllerException;
import net.jatec.ironmailer.controller.MailWorkerBean;
import net.jatec.ironmailer.framework.ServletTools;


class AddressesAction implements ActionDispatcher.ActionStrategy
{
    private final Logger log = Logger.getLogger(AddressesAction.class);

    public void process(ServletRequest req, MailWorkerBean wb, Redirector redirector, Map objectModel)
	throws ControllerException
    {
	// ensure contact list is loaded
	wb.setContactList();
	
	boolean isDelete = ServletTools.getBoolean(req,"delete");
	if (isDelete) {
	    int index = ServletTools.getInteger(req,"contactNr", true);
	    wb.getContactListController().deleteContact(index);
	}
    }
}

==> ironmailer-0.8.2-src.tar.bz2: src/logic/net/jatec/ironmailer/controller/action/AddressesAction.java <==
/* 
 *   Copyright (C) 2002, 2003, 2004 Jatec AG, Switzerland
 *
 * This file is part of IronMailer.
 *
 * IronMailer is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

package net.jatec.ironmailer.controller.action;

import java.util.Map;
import javax.servlet.ServletRequest;
import org.apache.cocoon.environment.Redirector;
import org.apache.log4j.Logger;

import net.jatec.ironmailer.controller.ControllerException;
import net.jatec.ironmailer.controller.MailWorkerBean;
import net.jatec.ironmailer.framework.ServletTools;


class AddressesAction implements ActionDispatcher.ActionStrategy
{
    private final Logger log = Logger.getLogger(AddressesAction.class);

    public void process(ServletRequest req, MailWorkerBean wb, Redirector redirector, Map objectModel)
	throws ControllerException
    {
	// ensure contact list is loaded
	wb.setContactList();
	
	if (ServletTools.getBoolean(req,"delete")) {
	    int index = ServletTools.getInteger(req,"contactNr", true);
	    wb.getContactListController().deleteContact(index);
	}
	else
	    if (ServletTools.getBoolean(req,"sort")) {
		boolean ascending = ServletTools.getBoolean(req,"up",true);
		String field = ServletTools.getString(req,"field",true);
		wb.getContactListController().sort(field, ascending);
	    }
    }
}
